@@ -13,7 +13,6 @@
 #include <KMessageBox>
 #include <KUrlComboBox>
 #include <KWindowConfig>
-#include <kwidgetsaddons_version.h>
 
 #include <QDir>
 #include <QPushButton>
@@ -104,23 +103,14 @@ void ExtractionDialog::slotAccepted()
         while (1) {
             if (QDir(pathWithSubfolder).exists()) {
                 if (QFileInfo(pathWithSubfolder).isDir()) {
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                     int overwrite = KMessageBox::questionTwoActionsCancel(
                         this,
-#else
-                    int overwrite = KMessageBox::questionYesNoCancel(
-                        this,
-#endif
                         xi18nc("@info", "The folder <filename>%1</filename> already exists. Are you sure you want to extract here?", pathWithSubfolder),
                         i18n("Folder exists"),
                         KGuiItem(i18n("Extract here")),
                         KGuiItem(i18n("Retry")));
 
-#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                     if (overwrite == KMessageBox::SecondaryAction) {
-#else
-                    if (overwrite == KMessageBox::No) {
-#endif
                         // The user clicked Retry.
                         continue;
                     } else if (overwrite == KMessageBox::Cancel) {
@@ -144,7 +134,7 @@ void ExtractionDialog::slotAccepted()
     }
 
     // Add new destination value to arkrc for quickExtractMenu.
-    KConfigGroup conf(KSharedConfig::openConfig(), "ExtractDialog");
+    KConfigGroup conf(KSharedConfig::openConfig(), QStringLiteral("ExtractDialog"));
     QStringList destHistory = conf.readPathEntry("DirHistory", QStringList());
     destHistory.prepend(destinationPath);
     destHistory.removeDuplicates();
@@ -295,7 +285,7 @@ void ExtractionDialog::writeSettings()
     ArkSettings::self()->save();
 
     // Save dialog window size
-    KConfigGroup group(KSharedConfig::openConfig(), "ExtractDialog");
+    KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("ExtractDialog"));
     KWindowConfig::saveWindowSize(windowHandle(), group, KConfigBase::Persistent);
 }
 
@@ -307,10 +297,11 @@ void ExtractionDialog::setCurrentUrl(const QUrl &url)
 void ExtractionDialog::restoreWindowSize()
 {
   // Restore window size from config file, needs a windowHandle so must be called after show()
-  KConfigGroup group(KSharedConfig::openConfig(), "ExtractDialog");
+  KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("ExtractDialog"));
   KWindowConfig::restoreWindowSize(windowHandle(), group);
 }
 
 }
 
 #include "extractiondialog.moc"
+#include "moc_extractiondialog.cpp"
