@@ -76,6 +76,8 @@ QMimeType determineMimeType(const QString& filename, MimePreference mp)
          mimeFromContent == db.mimeTypeForName(QStringLiteral("application/gzip"))) ||
         (mimeFromExtension.inherits(QStringLiteral("application/x-bzip-compressed-tar")) &&
          mimeFromContent == db.mimeTypeForName(QStringLiteral("application/x-bzip"))) ||
+        (mimeFromExtension.inherits(QStringLiteral("application/x-bzip2-compressed-tar")) &&
+         mimeFromContent == db.mimeTypeForName(QStringLiteral("application/x-bzip2"))) ||
         (mimeFromExtension.inherits(QStringLiteral("application/x-xz-compressed-tar")) &&
          mimeFromContent == db.mimeTypeForName(QStringLiteral("application/x-xz"))) ||
         (mimeFromExtension.inherits(QStringLiteral("application/x-tarz")) &&
@@ -101,11 +103,6 @@ QMimeType determineMimeType(const QString& filename, MimePreference mp)
             return mimeFromExtension;
         }
 
-        // #354344: ISO files are currently wrongly detected-by-content.
-        if (mimeFromExtension.inherits(QStringLiteral("application/x-cd-image"))) {
-            return mimeFromExtension;
-        }
-
         qCDebug(ARK) << "Mimetype for filename extension (" << mimeFromExtension.name()
                        << ") did not match mimetype for content (" << mimeFromContent.name()
                        << "). Using content-based mimetype.";
